You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airflow.apache.org by ep...@apache.org on 2023/10/30 11:26:33 UTC

(airflow) 38/46: Add TriggerRule missing value in rest API (#35194)

This is an automated email from the ASF dual-hosted git repository.

ephraimanierobi pushed a commit to branch v2-7-test
in repository https://gitbox.apache.org/repos/asf/airflow.git

commit 7885869ec2d7b7d61e1bcc71023f7f60d39599fd
Author: Pankaj Singh <98...@users.noreply.github.com>
AuthorDate: Thu Oct 26 16:25:48 2023 +0530

    Add TriggerRule missing value in rest API (#35194)
    
    * Add TriggerRule missing in rest API
    
    * Update airflow/api_connexion/openapi/v1.yaml
    
    * Update airflow/www/static/js/types/api-generated.ts
    
    (cherry picked from commit e3b3d786787597e417f3625c6e9e617e4b3e5073)
---
 airflow/api_connexion/openapi/v1.yaml        | 12 +++++++++++-
 airflow/www/static/js/types/api-generated.ts | 14 ++++++++++++--
 2 files changed, 23 insertions(+), 3 deletions(-)

diff --git a/airflow/api_connexion/openapi/v1.yaml b/airflow/api_connexion/openapi/v1.yaml
index ce038a3aaf..dcb2ca6967 100644
--- a/airflow/api_connexion/openapi/v1.yaml
+++ b/airflow/api_connexion/openapi/v1.yaml
@@ -4722,19 +4722,29 @@ components:
       description: |
         Trigger rule.
 
-        *Changed in version 2.2.0*&#58; 'none_failed_min_one_success' is added as a possible value.
+        *Changed in version 2.2.0*&#58; 'none_failed_min_one_success' is added as a possible value. Deprecated 'dummy' and 'always' is added as a possible value
+
+        *Changed in version 2.3.0*&#58; 'all_skipped' is added as a possible value.
+
+        *Changed in version 2.5.0*&#58; 'one_done' is added as a possible value.
+
+        *Changed in version 2.7.0*&#58; 'all_done_setup_success' is added as a possible value.
       type: string
       enum:
         - all_success
         - all_failed
         - all_done
+        - all_done_setup_success
         - one_success
         - one_failed
+        - one_done
         - none_failed
         - none_skipped
         - none_failed_or_skipped
         - none_failed_min_one_success
         - dummy
+        - all_skipped
+        - always
 
     WeightRule:
       description: Weight rule.
diff --git a/airflow/www/static/js/types/api-generated.ts b/airflow/www/static/js/types/api-generated.ts
index 87feec6897..6e7051db3b 100644
--- a/airflow/www/static/js/types/api-generated.ts
+++ b/airflow/www/static/js/types/api-generated.ts
@@ -2201,7 +2201,13 @@ export interface components {
     /**
      * @description Trigger rule.
      *
      * *Changed in version 2.2.0*&#58; 'none_failed_min_one_success' is added as a possible value.
      *
      * @enum {string}
      */
@@ -2209,13 +2215,17 @@ export interface components {
       | "all_success"
       | "all_failed"
       | "all_done"
+      | "all_done_setup_success"
       | "one_success"
       | "one_failed"
+      | "one_done"
       | "none_failed"
       | "none_skipped"
       | "none_failed_or_skipped"
       | "none_failed_min_one_success"
-      | "dummy";
+      | "dummy"
+      | "all_skipped"
+      | "always";
     /**
      * @description Weight rule.
      * @enum {string}
@@ -2201,7 +2201,13 @@ export interface components {
      * @description Trigger rule.
      *
-     * *Changed in version 2.2.0*&#58; 'none_failed_min_one_success' is added as a possible value.
+     * *Changed in version 2.2.0*&#58; 'none_failed_min_one_success' is added as a possible value. Deprecated 'dummy' and 'always' is added as a possible value
+     *
+     * *Changed in version 2.3.0*&#58; 'all_skipped' is added as a possible value.
+     *
+     * *Changed in version 2.5.0*&#58; 'one_done' is added as a possible value.
+     *
+     * *Changed in version 2.7.0*&#58; 'all_done_setup_success' is added as a possible value.
      *
      * @enum {string}